@@ -58,19 +58,18 @@ class PortfolioFactory():
     # mathematical solution) Finally it should be defined how to handle
     # non-correct solutions
 
-    def __init__(self, configuration):
+    def __init__(self, properties=None):
         self.log = dna.logging.logger(__name__)
         # Other parameters are used in user's optimize() method
-        self._optimizer_parameters = configuration
+        self.properties = properties or {}
+        self.initialize(self.properties)
 
-        self.initialize(configuration)
-
-    def initialize(self, configuration):
+    def initialize(self, properties):
         ''' Users should overwrite this method '''
         pass
 
     @abc.abstractmethod
-    def optimize(self, date, to_buy, to_sell, parameters):
+    def optimize(self, to_buy={}, to_sell={}):
         ''' Users should overwrite this method '''
         pass
 
@@ -87,18 +86,15 @@ class PortfolioFactory():
         '''
         Process buy and sell signals from the simulation
         '''
-        alloc = {}
-
-        if signals['buy'] or signals['sell']:
-            # Compute the optimal portfolio allocation,
-            # Using user defined function
+        buy_sig, sell_sig = signals.get('buy', {}), signals.get('sell', {})
+        if buy_sig or sell_sig:
+            # Compute optimal portfolio allocation, Using user defined function
             try:
-                alloc, e_ret, e_risk = self.optimize(
-                    self.date, signals['buy'], signals['sell'],
-                    self._optimizer_parameters)
+                alloc, e_ret, e_risk = self.optimize(buy_sig, sell_sig)
             except Exception, error:
                 raise PortfolioOptimizationFailed(
                     reason=error, date=self.date, data=signals)
+
         return _remove_useless_orders(alloc)
 
     def advise(self, **kwargs):
@@ -107,4 +103,4 @@ class PortfolioFactory():
         (maw_weigth, max_assets, max_frequency, commission cost)
         '''
         for name, value in kwargs.iteritems():
-            self._optimizer_parameters[name] = value
+            self.properties[name] = value
