@@ -19,6 +19,7 @@ from dna.time_utils import normalize_date_format
 
 
 def is_live(current_date):
+    ''' True if the given date is in the (utc) future '''
     return (current_date > pd.datetime.now(pytz.utc))
 
 
@@ -29,9 +30,12 @@ def next_tick(date, interval=15):
     # Intuition works with utc dates, conversion are made for I/O
     now = dt.datetime.now(pytz.utc)
     live = False
+    # Sleep until we reach the given date
     while now < date:
         time.sleep(interval)
+        # Update current time
         now = dt.datetime.now(pytz.utc)
+        # Since we're here, we waited a future date, so this is live trading
         live = True
     return live
 
@@ -39,11 +43,14 @@ def next_tick(date, interval=15):
 def intuition_module(location):
     ''' Build the module path and import it '''
     path = location.split('.')
+    # Get the last field, i.e. the object name in the file
     obj = path.pop(-1)
     return dna.utils.dynamic_import('.'.join(path), obj)
 
 
-def build_trading_timeline(start, end, freq='D'):
+# NOTE Without the freq param, their might be some smart refactor to do here
+def build_trading_timeline(start, end):
+    ''' Build the daily-based index we will trade on '''
     EMPTY_DATES = pd.date_range('2000/01/01', periods=0, tz=pytz.utc)
     now = dt.datetime.now(tz=pytz.utc)
 
@@ -53,8 +60,7 @@ def build_trading_timeline(start, end, freq='D'):
             bt_dates = EMPTY_DATES
             live_dates = pd.date_range(
                 start=now,
-                end=normalize_date_format('23h59'),
-                freq=freq)
+                end=normalize_date_format('23h59'))
         else:
             end = normalize_date_format(end)
             if end < now:
@@ -66,7 +72,7 @@ def build_trading_timeline(start, end, freq='D'):
             elif end > now:
                 # Live trading from now to end
                 bt_dates = EMPTY_DATES
-                live_dates = pd.date_range(start=now, end=end, freq=freq)
+                live_dates = pd.date_range(start=now, end=end)
     else:
         start = normalize_date_format(start)
         if start < now:
@@ -90,22 +96,18 @@ def build_trading_timeline(start, end, freq='D'):
                     bt_dates = pd.date_range(
                         start=start, end=now - pd.datetools.day)
 
-                    live_dates = pd.date_range(
-                        start=now, end=end, freq=freq)
+                    live_dates = pd.date_range(start=now, end=end)
         elif start > now:
             if not end:
                 # Live trading from start to the end of the day
                 bt_dates = EMPTY_DATES
                 live_dates = pd.date_range(
                     start=start,
-                    end=normalize_date_format('23h59'),
-                    freq=freq)
+                    end=normalize_date_format('23h59'))
             else:
                 # Live trading from start to end
                 end = normalize_date_format(end)
                 bt_dates = EMPTY_DATES
-                live_dates = pd.date_range(
-                    start=start,
-                    end=end, freq=freq)
+                live_dates = pd.date_range(start=start, end=end)
 
     return bt_dates + live_dates
